{- |
Copyright: (c) 2022 Kowainik
SPDX-License-Identifier: MIT
Maintainer: Kowainik <xrom.xkov@gmail.com>

Full-featured test project
-}

module FullBatteries
    ( projectName
    ) where


projectName :: String
projectName = "full-batteries"
